@@ -1,11 +1,12 @@
 `BasicHTML` <-
-function(cmds=NULL, HTMLobjects, Captions, MenuLabels, Comments, file="tmp.html", title="", width=480, height=480, FRAMES=FALSE, JSCPATH = "jsc", LaunchPage = FALSE, verbose=0){
+function(cmds=NULL, HTMLobjects, Captions, MenuLabels, Comments, file="tmp.html", title="", width=480, height=480, FRAMES=FALSE, JSCPATH = "jsc", LaunchPage = FALSE, APPEND = FALSE, verbose=0){
 	#BasicHTML(cmds = c("plot(rnorm(100));","plot(1:10);"), HTMLobjects = list("Fig1.png", "Fig2.png"), Captions=c("Gaussian noise","seq 1:10"))
 	#x <- cbind.data.frame(x1 = round(rnorm(10),3), x2 = round(runif(10),3));
 	#attr(x, "HEADER") <- "some random numbers";
 	#BasicHTML(HTMLobjects = list("Fig1.png", x, "Fig2.png"), Captions=c("Gaussian noise","Gaussian and uniform random numbers", "seq 1:10"), file = paste(Sys.getenv("HOME"), "/public_html/tmp/tmp.html",sep=""), JSCPATH = "../jsc")
 	
-  require(R2HTML);require(Cairo);
+  require(R2HTML);
+  #require(Cairo);
   graphIndex <- sapply(HTMLobjects,is.character);
   graphfiles <- unlist(HTMLobjects[graphIndex]);
   header <- NULL;
@@ -19,14 +20,19 @@ function(cmds=NULL, HTMLobjects, Captions, MenuLabels, Comments, file="tmp.html"
   } else  {
   	stopifnot(length(cmds)==length(graphfiles));
     DoNotPlot <- FALSE;
-    require(Cairo);
     CairoWorks();
   }
   
   if (verbose >1) browser();
   
-  if(! FRAMES) MyReportBegin(file=file, title = title, header = header)
-  MenuNumber <- 1;
+  if(! FRAMES & !APPEND ) MyReportBegin(file=file, title = title, header = header);
+  if (APPEND & FRAMES ){
+  	tmp <- scan(paste(substring(file,1,nchar(file)-10), "_menu.html",sep=""), what = "");
+  	ExistingLabels <- grep("#Num", tmp);
+  	MenuNumber <- length(ExistingLabels) + 1;
+  } else {
+    MenuNumber <- 1;}
+  
   for (i in seq(along= HTMLobjects)){
   	if (FRAMES){
   	  if (!is.null(Comments)) if (nchar(Comments[i])>0) HTML(Comments[i]);
@@ -54,7 +60,10 @@ function(cmds=NULL, HTMLobjects, Captions, MenuLabels, Comments, file="tmp.html"
 	}
   }
 
-  if(! FRAMES) MyReportEnd(file=file);
+
+ #for now I am not adding a clean end of html footer in order to keep the pages open for appending operations
+ #most browsers seem to be able to handle this just fine...
+ # if(! FRAMES) MyReportEnd(file=file);
   if (LaunchPage) system(paste("open ", file))
 }
 
